pub struct ECTranscript<C: PrimeOrderCurve, T> {
sponge: T,
transcript: Transcript<C::Base>,
debug: bool,
}Expand description
A transcript that operates over the base field of a prime-order curve, while also allowing for the absorption and sampling of scalar field elements (and of course, EC points).
Fields
sponge: TThe sponge that this writer is using to append/squeeze elements.
transcript: Transcript<C::Base>A mutable transcript which keeps a record of all the append/squeeze operations.
debug: boolWhether to print debug information.
Implementations
Sourceimpl<C: PrimeOrderCurve, Tr: ECTranscriptSponge<C> + Default> ECTranscript<C, Tr>
impl<C: PrimeOrderCurve, Tr: ECTranscriptSponge<C> + Default> ECTranscript<C, Tr>
Sourcepub fn get_transcript(self) -> Transcript<C::Base>
pub fn get_transcript(self) -> Transcript<C::Base>
Destructively extract the transcript produced by this writer.
This should be the last operation performed on a TranscriptWriter.
Sourcepub fn new(label: &str) -> Self
pub fn new(label: &str) -> Self
Creates an empty sponge.
label is an identifier used for debugging purposes.
Sourcepub fn new_with_debug(label: &str) -> Self
pub fn new_with_debug(label: &str) -> Self
Creates an empty sponge in debug mode (i.e. with debug information printed).
label is an identifier used for debugging purposes.